/*************************************************
 **                                             **
 **   sc_clock.h                                **
 **                                             **
 **     SoftC Clock/Calendar functions header   **
 **                                             **
 **          Copyright (C) 1989-1992 by         **
 **               SoftC, Ltd.                   **
 **               16820 3rd St NE               **
 **               Anoka, MN 55304               **
 **               (612) 434-6968                **
 **                                             **
 **             All rights reserved.            **
 *************************************************/



/**********
 *
 *  Defines
 *
 **********/




#define SC_GREGOR     1            /* Gregorian date "mm/dd/yy" */
#define SC_GREGORL    2            /* Gregorian date "mm/dd/yyyy" */
#define SC_JULIAN     3            /* Julian date "yyyy/ddd" */
#define SC_YMD        4            /* dBASE date "yyyymmdd" */
#define SC_DMY        5            /* European Military date "ddmmyy" */
#define SC_GERMAN     6            /* German date "dd.mm.yy" */
#define SC_EURODATE   SC_GERMAN
#define SC_GERMANL    7            /* German date "dd.mm.yyyy" */
#define SC_EURODATEL  SC_GERMANL
#define SC_BRITISH    8            /* British date "dd/mm/yy" */
#define SC_BRITISHL   9            /* British date "dd/mm/yyyy" */
#define SC_FRENCH    10            /* French date "dd/mm/yy" */
#define SC_FRENCHL   11            /* French date "dd/mm/yyyy" */
#define SC_ITALIAN   12            /* Italian date "dd-mm-yy" */
#define SC_ITALIANL  13            /* Italian date "dd-mm-yyyy" */
#define SC_ENSI      14     	   /* Ensi date "yy.mm.dd" */
#define SC_ENSIL     15    	   /* Ensi date "yyyy.mm.dd" */

#define SC_CSHMS      1            /* colon separated time "hh:mm:ss" */
#define SC_MIL        2            /* Military time 0000 - 2359 */



#ifdef __ANSI_PROTOTYPES__
#ifdef __cplusplus
extern "C" {
#endif

/**********
 *
 *  Set default date style
 *
 **********/



INT PROTOS sccdstyle(  INT );            /* set date style */

INT PROTOS sccdgstyle( INT F_PTR,        /* current date style */
		       CHAR F_PTR );     /* date format string */




/**********
 *
 *  Integer Date Source Function Prototypes
 *
 **********/



INT PROTOS sccdi2l(    LONG F_PTR,       /* number of days since 1/1 0001 */
		       INT,              /* year */
		       INT,              /* month */
		       INT );            /* day */

INT PROTOS sccdi2s(    CHAR F_PTR,       /* date string */
		       INT,              /* date string format (YMD, GREG, JUL) */
		       INT,              /* year */
		       INT,              /* month */
		       INT );            /* day */

INT PROTOS sccdiget(   INT F_PTR,        /* current DOS year */
		       INT F_PTR,        /*             month */
		       INT F_PTR,        /*             day of month */
		       INT F_PTR);       /*             day of week */

INT PROTOS sccdileap(  INT );            /* year */

INT PROTOS sccdiperm(  INT F_PTR,        /* number of days in month */
		       INT,              /* desired year */
		       INT);             /* desired month */




/**********
 *
 *  Long Date Source Function Prototypes
 *
 **********/




INT PROTOS sccdl2dow(  INT F_PTR,        /* day number (0-6) */
		       LONG );           /* LONG date source */

INT PROTOS sccdl2i(    INT F_PTR,        /* year */
		       INT F_PTR,        /* month */
		       INT F_PTR,        /* day */
		       LONG );           /* LONG date source */

INT PROTOS sccdl2sx(   CHAR F_PTR,       /* date string */
		       INT,              /* date string format */
		       LONG);            /* number of days since 1/1/00 */




/**********
 *
 *  String Date Source Function Prototypes
 *
 **********/



INT PROTOS sccds2day(  CHAR F_PTR,       /* day of week string */
		       CHAR F_PTR,       /* source date string */
		       INT );            /* source date string format */

INT PROTOS sccds2dow(  INT F_PTR,        /* day of week number */
		       CHAR F_PTR,       /* source date string */
		       INT );            /* source date string format */

INT PROTOS sccds2i(    INT F_PTR,        /* year */
		       INT F_PTR,        /* month */
		       INT F_PTR,        /* day */
		       CHAR F_PTR,       /* date string */
		       INT );            /* string format */

INT PROTOS sccds2lx(   LONG F_PTR,       /* number of days since 1/1 0001 */
		       CHAR F_PTR,       /* date string */
		       INT );            /* date string format (YMD,GREG, JUL) */

INT PROTOS sccds2mon(  CHAR F_PTR,        /* month of year string */
		       CHAR F_PTR,       /* source date string */
		       INT );            /* source date string format */

INT PROTOS sccds2s(    CHAR F_PTR,       /* output date string */
		       INT,              /* output string format */
		       CHAR F_PTR,       /* source date string */
		       INT );            /* source string format */

INT PROTOS sccdsday(   CHAR F_PTR,       /* day of week text string */
		       INT );            /* numeric day of week */

INT PROTOS sccdsdiff(  LONG F_PTR,       /* difference in days */
		       CHAR F_PTR,       /* date string */
		       INT,              /* string format (YMD, GREG, JULIAN) */
		       CHAR F_PTR,       /* date string */
		       INT);             /* string format (YMD, GREG, JULIAN) */

INT PROTOS sccdsget(   CHAR F_PTR,       /* DOS date string */
		       INT );            /* date string format */

INT PROTOS sccdsleap(  CHAR F_PTR,       /* date string */
		       INT );            /* string format (YMD,GREG,JULIAN) */

INT PROTOS sccdsmonth( CHAR F_PTR,       /* month text string */
		       INT );            /* numeric month */

INT PROTOS sccdsperm(  INT F_PTR,        /* number of days in month */
		       CHAR F_PTR,       /* date string */
		       INT );            /* string format (YMD, GREG, JUL) */

INT PROTOS sccdsvalid( CHAR F_PTR,       /* date string */
		       INT );            /* string format (YMD,GREG,JULIAN) */





/**********
 *
 *  Integer Clock Source Function Prototypes
 *
 **********/




INT PROTOS sccti2s(    CHAR F_PTR,       /* time string */
		       INT,              /* string format (H:M:S) */
		       INT,              /* hours */
		       INT,              /* minutes */
		       INT);             /* seconds */

INT PROTOS scctiget(   INT F_PTR,        /* current DOS hour */
		       INT F_PTR,        /*             minute */
		       INT F_PTR,        /*             second */
		       INT F_PTR );      /*             hundredths of second */






/**********
 *
 *  String Clock Source Function Prototypes
 *
 **********/




INT PROTOS sccts2i(    INT F_PTR,        /* hours */
		       INT F_PTR,        /* minutes */
		       INT F_PTR,        /* seconds */
		       CHAR F_PTR,       /* time string */
		       INT);             /* string format (H:M:S) */

INT PROTOS scctsdiff(  LONG F_PTR,       /* number of seconds difference */
		       CHAR F_PTR,       /* time 1 */
		       INT,              /* string format */
		       CHAR F_PTR,       /* time 2 */
		       INT);             /* string format (H:M:S) */

INT PROTOS scctsget(   CHAR F_PTR,       /* current time in string format */
		       INT);             /* time string format (MIL, H:M:S) */

INT PROTOS scctsvalid( CHAR F_PTR,       /* time string */
		       INT);             /* string format (H:M:S) */
#ifdef __cplusplus
}
#endif
#endif



